@@ -5,7 +5,7 @@ from basxbread.utils.urls import (
     model_urlname,
     reverse_model,
 )
-from basxbread.views import AddView, BrowseView, EditView
+from basxbread.views import AddView, EditView
 from django.views.generic import RedirectView
 
 import basxconnect.core.views.tag_views
@@ -126,10 +126,8 @@ urlpatterns = [
     *default_model_paths(
         models.Term,
         addview=AddView._with(fields=["term", "vocabulary"]),
-        editview=EditView._with(fields=["term", "slug"]),
-        browseview=TermsBrowseView._with(
-            rowclickaction=BrowseView.gen_rowclickaction("edit", return_to_current=True)
-        ),
+        editview=EditView._with(fields=["term", "slug", "disabled"]),
+        browseview=TermsBrowseView,
     ),
     *default_model_paths(
         models.Vocabulary,
