@@ -7,8 +7,9 @@ from basxconnect.core.models import Term, Vocabulary
 
 
 class TermsBrowseView(BrowseView):
-    def __init__(self, *args, **kwargs):
-        super().__init__(*args, **kwargs)
+    rowclickaction = BrowseView.gen_rowclickaction("edit", return_to_current=True)
+    rowactions = [BrowseView.deletelink()]
+    columns = ["term", "slug"]
 
     def get(self, *args, **kwargs):
         vocabulary = Vocabulary.objects.filter(
@@ -33,7 +34,7 @@ class TermsBrowseView(BrowseView):
         return super().get(*args, **kwargs)
 
     def get_queryset(self):
-        qs = super().get_queryset()
+        qs = Term.objects.including_disabled()
         vocabulary_slug = self.request.GET.get("vocabulary_slug")
         if vocabulary_slug:
             qs = qs.filter(vocabulary__slug=vocabulary_slug)
